/*
 *
 Project name:
       UNI Hall Click
 Copyright:
      (c) mikroElektronika, 2014.
 Revision History:
      20140820:
      - Initial release (RD);
 Description:
      UUNI HALL click is a simple solution for adding an unipolar Hall switch to
      your design. It carries the Melexis US5881 unipolar Hall-effect switch and
      a 74LVC1T45 single bit, dual supply translating transceiver. UNI HALL click
      communicates with the target board through the mikroBUS INT line. The
      board is designed to use either a 3.3V or 5V power supply (which also defines the
      logic level of the output signal).
      The unipolar Hall effect sensor on UNI HALL click is sensitive to north pole magnetic
      fieldswhen exposed to such a field, it outputs a LOW logic level. Othewise the
      output is a HIGH logic level. In its simplest application, UNI HALL click
      can be employed as part of a long lasting contactless proximity switch.
      However, magnets can be employed in various ways to infer the speed,
      position, or other properties of an object; there are countless ways to utilize
      UNI HALL click in your design.

 Test configuration:
     MCU:             P32MX795F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61156F.pdf
     Dev.Board:       EasyPIC Fusion v7
                      http://www.mikroe.com/easypic-fusion/
     Oscillator:      XT-PLL, 80.000MHz
     ext. modules:    BI Hall Click
                      http://www.mikroe.com/click/bi-hall/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/mikroc/pic32/
 NOTES:
      - Place UNI Hall Click board in the mikroBUS socket 1.
      - Set development board J5 jumper according to SMD jumper on click board. By default it's soldered in the 3.3V position.
      - Turn On SW15-3 switches for PORTB LEDs.

*/

char cnt, old_cnt;

void int1_interrupt() iv IVT_EXTERNAL_1 ilevel 4 ics ICS_AUTO {
    cnt++;
    INT1IF_bit = 0;
}

void main() {
   AD1PCFG     = 0xFFFF;               // Turning all analog pins to digital
   TRISE8_bit  = 1;                    // Set RE8 pin as input
   TRISB       = 0;                    // Set PORTB as output
   LATB        = 0;                    // Clear PORTB
   LATE        = 0;                    // Reset PortE
   cnt         = 0;
   old_cnt = cnt;

   INT1IP0_bit = 0;                   // Set INT1 interrupt
   INT1IP1_bit = 0;                   // Set interrupt priorities
   INT1IP2_bit = 1;                   // Set inrrupt priority to 4
   INT1IE_bit  = 1;                   // Set interrupt on INT1 (RE8) to be enabled
   INT1EP_bit  = 1;                   // Interrupt on rising edge
   EnableInterrupts();                // Enable interruts as previously set
   
   while(1) {
      if (old_cnt != cnt) {
         PORTB = cnt;
         old_cnt = cnt;
      }
   }
}